@@ -48,8 +48,8 @@ def add_alarm_status(
         print(new_alarm_status)
     """
     alarm_status_input = AddAlarmStatusInput(name=name)
-    if (name is ""):
-      print ("you cant leave the name parameter empt")
+    if (name == ""):
+      print ("you cant leave the name parameter empty")
     elif name!=str:
       print ("the input must be a text, example name=''new name''")
     else:
